import pathlib
HERE = pathlib.Path(__file__).parent
dataLoadLogs = HERE / "logs" / "dataLoadLogs.txt"
classificationTrainingLogs = HERE / "logs" / "classificationTrainingLogs.txt"
fileOperationLogs = HERE / "logs" / "fileOperationLogs.txt"
predictionLogs = HERE / "logs" / "predictionLogs.txt"
dataPreprocessingLogs = HERE/"logs"/"dataPreprocessingLogs.txt"
RegressionTrainingLogs = HERE/"logs"/"RegressionTrainingLogs.txt"
dataVisualizationLogs = HERE/"logs"/"dataVisualizationLogs.txt"